Kaylee
======

Kaylee is distributed and volunteer in-browser computing framework.
It is written in Python, CoffeeScript and JavaScript.


Is it ready yet?
================

**No!** The Kaylee promise is that each tagged version is self-contained 
and working fine, but the API is not stable yet and there might be 
dramatic changes in future.


Where are the docs?
===================

Right here, in ``/doc``, or at http://kaylee.znasibov.info/docs

I need help!
============

Feel free to report an issue on github: https://github.com/BasicWolf/Kaylee
